@@ -34,15 +34,17 @@ def uuid_name_to_number(uuid_name):
 
 def id_name_to_number(id_name):
     """Converts id name to number."""
-    if '-' in id_name:
-        return uuid_name_to_number(id_name)
-    return UUID(int=int(id_name))
+    try:
+        return UUID(id_name)
+    except ValueError:
+        return UUID(int=int(id_name))
 
 
 def id_number_to_name(id_number):
     """Converts id number to name."""
-    if id_number.int <= 0xffffffffffff:
-        return str(id_number.int)
+    id_int = id_number.int
+    if id_int < 2**64:
+        return str(id_int)
     return str(id_number)
 
 
