@@ -28,6 +28,10 @@ class Field:
 
     # pylint: disable=too-few-public-methods
 
+    @abstractmethod
+    def filter_values(self, values):
+        """Returns an SQL string for filter values."""
+
     @abstractmethod
     def filter_condition(self, values):
         """Returns an SQL condition for the filter query parameter."""
