@@ -366,24 +366,24 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         updated with something like the following:
 
         env.data_by_lid = {
-            1: {
-                'relationships': {
-                    'one_one_remote': {
-                        'data': {
-                            'type': 'one_one_remotes',
-                            'id': UUID_21,
-                        },
-                        'links': {
-                            'self': '/centers/1/relationships/one_one_remote',
-                            'related': '/centers/1/one_one_remote',
-                        },
-                    },
+          1: {
+            'relationships': {
+              'one_one_remote': {
+                'data': {
+                  'type': 'one_one_remotes',
+                  'id': UUID_21,
                 },
+                'links': {
+                  'self': '/resources/centers/1/relationships/one_one_remote',
+                  'related': '/resources/centers/1/one_one_remote',
+                },
+              },
             },
-            2: {
-                ...,
-            },
-            ...
+          },
+          2: {
+            ...,
+          },
+          ...
         }
         """
         stmt = (f'SELECT {self.rfkey}, id '
@@ -406,9 +406,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 },
             }
@@ -437,9 +437,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 },
             }
@@ -471,18 +471,18 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         with something like the following:
 
         env.data = {
-            'relationships': {
-                'one_one_remote': {
-                    'data': {
-                        'type': 'one_one_remotes',
-                        'id': UUID_21,
-                    },
-                    'links': {
-                        'self': '/centers/1/relationships/one_one_remote',
-                        'related': '/centers/1/one_one_remote',
-                    },
-                },
+          'relationships': {
+            'one_one_remote': {
+              'data': {
+                'type': 'one_one_remotes',
+                'id': UUID_21,
+              },
+              'links': {
+                'self': '/resources/centers/1/relationships/one_one_remote',
+                'related': '/resources/centers/1/one_one_remote',
+              },
             },
+          },
         }
         """
         stmt = (f"SELECT id "
@@ -502,10 +502,10 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         env.data.setdefault('relationships', {})[self.name] = {
             'data': rel_data,
             'links': {
-                'self': (f'/{self.collection.name}/{env.obj.id.name}/'
+                'self': (f'/resources/{self.collection.name}/{env.obj.id.name}/'
                          f'relationships/{self.name}'),
-                'related': (f'/{self.collection.name}/{env.obj.id.name}/'
-                            f'{self.name}'),
+                'related': (f'/resources/{self.collection.name}/'
+                            f'{env.obj.id.name}/{self.name}'),
             },
         }
 
@@ -533,9 +533,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 }
             }
@@ -585,7 +585,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                         },
                     },
                     'links': {
-                        'self': '/one_one_remotes/UUID_21',
+                        'self': '/resources/one_one_remotes/UUID_21',
                     },
                 },
             },
@@ -622,8 +622,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         env.data.setdefault('relationships', {})[self.name] = {
             'data': rel_data,
             'links': {
-                'self': (f'/{env.related.relationship.collection.name}/'
-                         f'{env.related.id.name}')
+                'self':
+                    (f'/resources/{env.related.relationship.collection.name}/'
+                     f'{env.related.id.name}')
             },
         }
 
@@ -647,7 +648,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                         },
                     },
                     'links': {
-                        'self': '/one_one_remotes/UUID_21',
+                        'self': '/resources/one_one_remotes/UUID_21',
                     },
                 },
             },
@@ -687,8 +688,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{env.related.relationship.collection.name}/'
-                             f'{env.related.id.name}')
+                    'self': (f'/resources'
+                             f'/{env.related.relationship.collection.name}'
+                             f'/{env.related.id.name}')
                 },
             }
 
@@ -734,27 +736,27 @@ class OneToManyRelationship(ToManyRelationship):
         updated with something like the following:
 
         env.data_by_lid = {
-            1: {
-                'relationships': {
-                    'one_manys': {
-                        'data': [
-                            {
-                                'type': 'one_manys',
-                                'id': UUID_41,
-                            },
-                            ...
-                        ],
-                        'links': {
-                            'self': '/centers/1/relationships/one_manys',
-                            'related': '/centers/1/one_manys',
-                        },
-                    },
+          1: {
+            'relationships': {
+              'one_manys': {
+                'data': [
+                  {
+                    'type': 'one_manys',
+                    'id': UUID_41,
+                  },
+                  ...
+                ],
+                'links': {
+                  'self': '/resources/centers/1/relationships/one_manys',
+                  'related': '/resources/centers/1/one_manys',
                 },
+              },
             },
-            2: {
-                ...,
-            },
-            ...
+          },
+          2: {
+            ...,
+          },
+          ...
         }
         """
         stmt = (f'SELECT {self.rfkey}, id '
@@ -779,9 +781,9 @@ class OneToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 }
             }
@@ -812,9 +814,9 @@ class OneToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 }
             }
@@ -855,8 +857,8 @@ class OneToManyRelationship(ToManyRelationship):
                         ...
                     ],
                     'links': {
-                        'self': '/centers/1/relationships/one_manys',
-                        'related': '/centers/1/one_manys',
+                        'self': '/resources/centers/1/relationships/one_manys',
+                        'related': '/resources/centers/1/one_manys',
                     },
                 },
             },
@@ -877,10 +879,11 @@ class OneToManyRelationship(ToManyRelationship):
                 'id': id_number_to_name(rid),
             } for rid in rids],
             'links': {
-                'self': (f'/{self.collection.name}/{env.obj.id.name}/'
+                'self': (f'/resources/{self.collection.name}/{env.obj.id.name}/'
                          f'relationships/{self.name}'),
-                'related': (f'/{self.collection.name}/{env.obj.id.name}/'
-                            f'{self.name}'),
+                'related':
+                    (f'/resources/{self.collection.name}/{env.obj.id.name}/'
+                     f'{self.name}'),
             },
         }
 
@@ -910,9 +913,9 @@ class OneToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 }
             }
@@ -964,7 +967,7 @@ class OneToManyRelationship(ToManyRelationship):
                     ...
                     ],
                     'links': {
-                        'self': '/one_manys/UUID_41',
+                        'self': '/resources/one_manys/UUID_41',
                     },
                 },
             },
@@ -998,7 +1001,8 @@ class OneToManyRelationship(ToManyRelationship):
         env.data.setdefault('relationships', {})[self.name] = {
             'data': rel_data,
             'links': {
-                'self': f'/{self.rtable.collection.name}/{env.related.id.name}'
+                'self': (f'/resources/{self.rtable.collection.name}'
+                         f'/{env.related.id.name}')
             },
         }
 
@@ -1024,7 +1028,7 @@ class OneToManyRelationship(ToManyRelationship):
                     ...
                     ],
                     'links': {
-                        'self': '/one_manys/UUID_41',
+                        'self': '/resources/one_manys/UUID_41',
                     },
                 },
             },
@@ -1063,7 +1067,7 @@ class OneToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
                     'related': (f'/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
@@ -1152,27 +1156,27 @@ class ManyToManyRelationship(ToManyRelationship):
         updated with something like the following:
 
         env.data_by_lid = {
-            1: {
-                'relationships': {
-                    'many_manys': {
-                        'data': [
-                            {
-                                'type': 'many_manys',
-                                'id': UUID_51,
-                            },
-                            ...
-                        ],
-                        'links': {
-                            'self': '/centers/1/relationships/many_manys',
-                            'related': '/centers/1/many_manys',
-                        },
-                    },
+          1: {
+            'relationships': {
+              'many_manys': {
+                'data': [
+                  {
+                    'type': 'many_manys',
+                    'id': UUID_51,
+                  },
+                  ...
+                ],
+                'links': {
+                  'self': '/resources/centers/1/relationships/many_manys',
+                  'related': '/resources/centers/1/many_manys',
                 },
+              },
             },
-            2: {
-                ...,
-            },
-            ...
+          },
+          2: {
+            ...,
+          },
+          ...
         }
         """
         stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
@@ -1197,9 +1201,9 @@ class ManyToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 },
             }
@@ -1231,9 +1235,9 @@ class ManyToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 },
             }
@@ -1274,8 +1278,8 @@ class ManyToManyRelationship(ToManyRelationship):
                         ...
                     ],
                     'links': {
-                        'self': '/centers/1/relationships/many_manys',
-                        'related': '/centers/1/many_manys',
+                        'self': '/resources/centers/1/relationships/many_manys',
+                        'related': '/resources/centers/1/many_manys',
                     },
                 },
             }
@@ -1298,10 +1302,11 @@ class ManyToManyRelationship(ToManyRelationship):
                 'id': id_number_to_name(rid),
             } for rid in rids],
             'links': {
-                'self': (f'/{self.collection.name}/{env.obj.id.name}/'
+                'self': (f'/resources/{self.collection.name}/{env.obj.id.name}/'
                          f'relationships/{self.name}'),
-                'related': (f'/{self.collection.name}/{env.obj.id.name}/'
-                            f'{self.name}'),
+                'related':
+                    (f'/resources/{self.collection.name}/{env.obj.id.name}/'
+                     f'{self.name}'),
             },
         }
 
@@ -1331,9 +1336,9 @@ class ManyToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self': (f'/{self.collection.name}/{lid_name}/'
+                    'self': (f'/resources/{self.collection.name}/{lid_name}/'
                              f'relationships/{self.name}'),
-                    'related': (f'/{self.collection.name}/{lid_name}/'
+                    'related': (f'/resources/{self.collection.name}/{lid_name}/'
                                 f'{self.name}'),
                 },
             }
@@ -1382,7 +1387,7 @@ class ManyToManyRelationship(ToManyRelationship):
                     ...
                     ],
                     'links': {
-                        'self': '/one_manys/UUID_41',
+                        'self': '/resources/one_manys/UUID_41',
                     },
                 },
             },
@@ -1417,7 +1422,8 @@ class ManyToManyRelationship(ToManyRelationship):
         env.data.setdefault('relationships', {})[self.name] = {
             'data': relationship_data,
             'links': {
-                'self': f'/{env.related.collection.name}/{env.related.id.name}'
+                'self': (f'/resources/{env.related.collection.name}'
+                         f'/{env.related.id.name}')
             },
         }
 
@@ -1443,7 +1449,7 @@ class ManyToManyRelationship(ToManyRelationship):
                     ...
                     ],
                     'links': {
-                        'self': '/one_manys/UUID_41',
+                        'self': '/resources/one_manys/UUID_41',
                     },
                 },
             },
@@ -1481,7 +1487,7 @@ class ManyToManyRelationship(ToManyRelationship):
             data.setdefault('relationships', {})[self.name] = {
                 'data': relationship_data,
                 'links': {
-                    'self':
-                        f'/{env.related.collection.name}/{env.related.id.name}'
+                    'self': (f'/resources/{env.related.collection.name}'
+                             f'/{env.related.id.name}')
                 },
             }
