@@ -57,12 +57,7 @@ from ajsonapi.postgres import (
     convert_unique_violation_error,
     convert_violation_error,
 )
-from ajsonapi.query import (
-    FilterNode,
-    parse_fields,
-    parse_page,
-    query_has_parameter,
-)
+from ajsonapi.query import FilterNode, parse_fields, parse_page
 from ajsonapi.responses import document_response, no_content_response
 from ajsonapi.uri.resource import Resource
 
@@ -133,7 +128,7 @@ class Collection(Resource):
     def parse_include(self, request_query, query, errors, allow):
         """Parses the request's include query parameter."""
 
-        if query_has_parameter(request_query, 'include'):
+        if 'include' in request_query:
             if not allow:
                 errors.append(QueryParameterUnsupportedError('include'))
                 return
@@ -159,7 +154,7 @@ class Collection(Resource):
                 path = match.group(1)
                 filter_values = set(urldecode(v) for v in value.split(','))
                 filter_path_values.append((path, filter_values))
-        if filter_path_values != []:
+        if filter_path_values:
             query['filters'] = self.filters_tree(FilterNode(),
                                                  filter_path_values, errors, [])
         else:
@@ -168,7 +163,7 @@ class Collection(Resource):
     def parse_sort(self, request_query, query, errors, allow):
         """Parses the request's sort query parameter."""
 
-        if query_has_parameter(request_query, 'sort'):
+        if 'sort' in request_query:
             if not allow:
                 errors.append(QueryParameterUnsupportedError('sort'))
                 return
